unit dmClient;

interface

uses
  SysUtils, Classes, SConnect, MConnect, DB, DBClient,
  uConfig,frmReconcileError;

type
  TDM = class(TDataModule)
    DBConnectionBroker: TConnectionBroker;
    DCOMConnection: TDCOMConnection;
    SocketConnection: TSocketConnection;
    WebConnection: TWebConnection;

{#DataComponentList}

    procedure DataModuleCreate(Sender: TObject);
    procedure DataModuleDestroy(Sender: TObject);
  private
    procedure DoOnReconcileError(DataSet: TCustomClientDataSet; E: EReconcileError; UpdateKind: TUpdateKind; var Action: TReconcileAction) ;
    procedure HookReconcileErrorEvent;
    procedure ConfigConnecton(AppServerParam:TAppServerParam);
    procedure Init;
    procedure UnInit;
  public
    { Public declarations }
  end;

var
  DM: TDM;

implementation

{$R *.dfm}

procedure TDM.DataModuleCreate(Sender: TObject);
begin
  Init;
end;

procedure TDM.Init;
begin
  ConfigConnecton(G_ConfigParam.AppServerParam);
  HookReconcileErrorEvent;
end;

procedure TDM.DataModuleDestroy(Sender: TObject);
begin
  UnInit;
end;

procedure TDM.UnInit;
begin
  //To Avoid AV Error when Free DM
  DBConnectionBroker.Free;
end;

procedure TDM.HookReconcileErrorEvent;
var I:Integer;
    CDS : TClientDataSet;
begin
  for I:=0 to Self.ComponentCount-1 do
  begin
    if Components[I] is TClientDataSet then
    begin
      CDS := Components[I] as TClientDataSet;
      CDS.OnReconcileError := DoOnReconcileError;
    end;
  end;
end;

procedure TDM.DoOnReconcileError(DataSet: TCustomClientDataSet;
  E: EReconcileError; UpdateKind: TUpdateKind;
  var Action: TReconcileAction);
begin
  Action := HandleReconcileError(DataSet,UpdateKind,E);
end;

procedure TDM.ConfigConnecton(AppServerParam: TAppServerParam);
begin
  case AppServerParam.ConnectionType of
    C_ConnectionType_DCOM   :
      begin
        DCOMConnection.ComputerName := AppServerParam.Location;
        DCOMConnection.ServerGUID := AppServerParam.ServerGUID;
        DBConnectionBroker.Connection := DCOMConnection;
      end;

    C_ConnectionType_Socket :
      begin
        SocketConnection.Host := AppServerParam.Location;
        SocketConnection.Port := AppServerParam.Port;
        SocketConnection.ServerGUID := AppServerParam.ServerGUID;
        DBConnectionBroker.Connection := SocketConnection;
      end;

    C_ConnectionType_Web    :
      begin
        WebConnection.URL := AppServerParam.Location;
        WebConnection.ServerGUID := AppServerParam.ServerGUID;
        DBConnectionBroker.Connection := WebConnection;
      end;

  end;
end;

end.


